package com.fs.store.service;

import java.util.List;
import com.fs.store.domain.FsStoreOrderItem;
import com.fs.store.param.FsStoreOrderParam;
import com.fs.store.vo.FsStoreOrderItemExportVO;
import com.fs.store.vo.FsStoreOrderItemVO;

/**
 * 订单详情Service接口
 *
 * @author fs
 * @date 2022-03-21
 */
public interface IFsStoreOrderItemService
{
    /**
     * 查询订单详情
     *
     * @param itemId 订单详情ID
     * @return 订单详情
     */
    public FsStoreOrderItem selectFsStoreOrderItemById(Long itemId);

    /**
     * 查询订单详情列表
     *
     * @param fsStoreOrderItem 订单详情
     * @return 订单详情集合
     */
    public List<FsStoreOrderItem> selectFsStoreOrderItemList(FsStoreOrderItem fsStoreOrderItem);

    /**
     * 新增订单详情
     *
     * @param fsStoreOrderItem 订单详情
     * @return 结果
     */
    public int insertFsStoreOrderItem(FsStoreOrderItem fsStoreOrderItem);

    /**
     * 修改订单详情
     *
     * @param fsStoreOrderItem 订单详情
     * @return 结果
     */
    public int updateFsStoreOrderItem(FsStoreOrderItem fsStoreOrderItem);

    /**
     * 批量删除订单详情
     *
     * @param itemIds 需要删除的订单详情ID
     * @return 结果
     */
    public int deleteFsStoreOrderItemByIds(Long[] itemIds);

    /**
     * 删除订单详情信息
     *
     * @param itemId 订单详情ID
     * @return 结果
     */
    public int deleteFsStoreOrderItemById(Long itemId);

    List<FsStoreOrderItemVO> selectFsStoreOrderItemListByOrderId(Long ordreId);

    List<FsStoreOrderItemExportVO> selectFsStoreOrderItemListExportVO(FsStoreOrderParam fsStoreOrder);

    Long countFsStoreOrderItemListExportVO(FsStoreOrderParam fsStoreOrder);

    int updateFsStoreOrderCode(Long orderId, String orderCode);
}
